@@ -20,6 +20,7 @@
 
 #include <QApplication>
 #include <QNetworkAccessManager>
+#include <QTimer>
 
 #include <KDBusService>
 #include <KNotification>
@@ -41,16 +42,16 @@ public:
         , m_nam(Q_NULLPTR)
     {}
 
-    void askPairingConfirmation(PairingHandler* d) override
+    void askPairingConfirmation(Device* device) override
     {
         KNotification* notification = new KNotification(QStringLiteral("pairingRequest"));
         notification->setIconName(QStringLiteral("dialog-information"));
         notification->setComponentName(QStringLiteral("kdeconnect"));
-        notification->setText(i18n("Pairing request from %1", getDevice(d->deviceLink()->deviceId())->name()));
+        notification->setText(i18n("Pairing request from %1", device->name().toHtmlEscaped()));
         notification->setActions(QStringList() << i18n("Accept") << i18n("Reject"));
-        connect(notification, &KNotification::ignored, d, &PairingHandler::rejectPairing);
-        connect(notification, &KNotification::action1Activated, d, &PairingHandler::acceptPairing);
-        connect(notification, &KNotification::action2Activated, d, &PairingHandler::rejectPairing);
+//         notification->setTimeout(PairingHandler::pairingTimeoutMsec());
+        connect(notification, &KNotification::action1Activated, device, &Device::acceptPairing);
+        connect(notification, &KNotification::action2Activated, device, &Device::rejectPairing);
         notification->sendEvent();
     }
 
