@@ -92,6 +92,8 @@ void NotificationsModel::setDeviceId(const QString& deviceId)
             this, &NotificationsModel::notificationRemoved);
     connect(m_dbusInterface, &OrgKdeKdeconnectDeviceNotificationsInterface::allNotificationsRemoved,
             this, &NotificationsModel::clearNotifications);
+    connect(m_dbusInterface, &OrgKdeKdeconnectDeviceNotificationsInterface::notificationUpdated,
+            this, &NotificationsModel::notificationUpdated);
 
     refreshNotificationList();
 
@@ -261,3 +263,9 @@ void NotificationsModel::clearNotifications()
         endRemoveRows();
     }
 }
+
+void NotificationsModel::notificationUpdated(const QString& id)
+{
+    //TODO only emit the affected indices
+    Q_EMIT dataChanged(index(0,0), index(m_notificationList.size() - 1, 0));
+}
