@@ -38,12 +38,13 @@ class Q_DECL_EXPORT LockDevicePlugin
     Q_PROPERTY(bool isLocked READ isLocked WRITE setLocked NOTIFY lockedChanged)
 
 public:
-    explicit LockDevicePlugin(QObject *parent, const QVariantList &args);
+    explicit LockDevicePlugin(QObject* parent, const QVariantList &args);
     ~LockDevicePlugin() override;
 
     bool isLocked() const;
     void setLocked(bool b);
 
+    QString dbusPath() const override;
     void connected() override;
     bool receivePackage(const NetworkPackage & np) override;
 
@@ -51,7 +52,6 @@ Q_SIGNALS:
     void lockedChanged(bool locked);
 
 private:
-    QString dbusPath() const;
     bool m_remoteLocked;
 
     OrgFreedesktopScreenSaverInterface* iface();
