@@ -26,6 +26,7 @@
 #include <QString>
 #include <QStringList>
 #include <QDir>
+#include <QPointer>
 
 #include "notification.h"
 
@@ -55,6 +56,7 @@ public Q_SLOTS:
 Q_SIGNALS:
     Q_SCRIPTABLE void notificationPosted(const QString& publicId);
     Q_SCRIPTABLE void notificationRemoved(const QString& publicId);
+    Q_SCRIPTABLE void notificationUpdated(const QString& publicId);
     Q_SCRIPTABLE void allNotificationsRemoved();
 
 private /*methods*/:
@@ -64,7 +66,7 @@ private /*methods*/:
 private /*attributes*/:
     const Device* m_device;
     KdeConnectPlugin* m_plugin;
-    QHash<QString, Notification*> m_notifications;
+    QHash<QString, QPointer<Notification>> m_notifications;
     QHash<QString, QString> m_internalIdToPublicId;
     int m_lastId;
 };
