@@ -35,13 +35,13 @@
 
 K_PLUGIN_FACTORY(ShareConfigFactory, registerPlugin<RunCommandConfig>();)
 
-RunCommandConfig::RunCommandConfig(QWidget *parent, const QVariantList& args)
+RunCommandConfig::RunCommandConfig(QWidget* parent, const QVariantList& args)
     : KdeConnectPluginKcm(parent, args, QStringLiteral("kdeconnect_runcommand_config"))
 {
-    QTableView *table = new QTableView(this);
+    QTableView* table = new QTableView(this);
     table->horizontalHeader()->setStretchLastSection(true);
     table->verticalHeader()->setVisible(false);
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    QVBoxLayout* layout = new QVBoxLayout(this);
     layout->addWidget(table);
     setLayout(layout);
 
@@ -70,15 +70,16 @@ void RunCommandConfig::load()
 
     QJsonDocument jsonDocument = QJsonDocument::fromJson(config()->get<QByteArray>(QStringLiteral("commands"), "{}"));
     QJsonObject jsonConfig = jsonDocument.object();
-    Q_FOREACH (const QString &key, jsonConfig.keys()) {
+    const QStringList keys = jsonConfig.keys();
+    for (const QString& key : keys) {
         const QJsonObject entry = jsonConfig[key].toObject();
         const QString name = entry[QStringLiteral("name")].toString();
         const QString command = entry[QStringLiteral("command")].toString();
 
-        QStandardItem *newName = new QStandardItem(name);
+        QStandardItem* newName = new QStandardItem(name);
         newName->setEditable(true);
         newName->setData(key);
-        QStandardItem *newCommand = new QStandardItem(command);
+        QStandardItem* newCommand = new QStandardItem(command);
         newName->setEditable(true);
 
         m_entriesModel->appendRow(QList<QStandardItem*>() << newName << newCommand);
@@ -114,7 +115,7 @@ void RunCommandConfig::save()
     }
     QJsonDocument document;
     document.setObject(jsonConfig);
-    config()->set(QStringLiteral("commands"), document.toJson());
+    config()->set(QStringLiteral("commands"), document.toJson(QJsonDocument::Compact));
 
     KCModule::save();
 
@@ -123,9 +124,9 @@ void RunCommandConfig::save()
 
 void RunCommandConfig::insertEmptyRow()
 {
-    QStandardItem *newName = new QStandardItem;
+    QStandardItem* newName = new QStandardItem;
     newName->setEditable(true);
-    QStandardItem *newCommand = new QStandardItem;
+    QStandardItem* newCommand = new QStandardItem;
     newName->setEditable(true);
 
     m_entriesModel->appendRow(QList<QStandardItem*>() << newName << newCommand);
