@@ -20,7 +20,7 @@
 
 #include "telephonyplugin.h"
 
-#include "sendsmsdialog.h"
+#include "sendreplydialog.h"
 
 #include <KLocalizedString>
 #include <QIcon>
@@ -33,11 +33,10 @@ K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_telephony.json"
 
 Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_TELEPHONY, "kdeconnect.plugin.telephony")
 
-TelephonyPlugin::TelephonyPlugin(QObject *parent, const QVariantList &args)
+TelephonyPlugin::TelephonyPlugin(QObject* parent, const QVariantList& args)
     : KdeConnectPlugin(parent, args)
     , m_telepathyInterface(QStringLiteral("org.freedesktop.Telepathy.ConnectionManager.kdeconnect"), QStringLiteral("/kdeconnect"))
 {
-    connect(&m_telepathyInterface, SIGNAL(messageReceived(QString,QString)), SLOT(sendSms(QString,QString)));
 }
 
 KNotification* TelephonyPlugin::createNotification(const NetworkPackage& np)
@@ -50,6 +49,7 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPackage& np)
     // In case telepathy can handle the message, don't do anything else
     if (event == QLatin1String("sms") && m_telepathyInterface.isValid()) {
         qCDebug(KDECONNECT_PLUGIN_TELEPHONY) << "Passing a text message to the telepathy interface";
+        connect(&m_telepathyInterface, SIGNAL(messageReceived(QString,QString)), SLOT(sendSms(QString,QString)), Qt::UniqueConnection);
         const QString messageBody = np.get<QString>(QStringLiteral("messageBody"),QLatin1String(""));
         QDBusReply<bool> reply = m_telepathyInterface.call(QStringLiteral("sendMessage"), phoneNumber, contactName, messageBody);
         if (reply) {
@@ -60,7 +60,7 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPackage& np)
     }
 
     QString content, type, icon;
-    KNotification::NotificationFlags flags = KNotification::CloseOnTimeout | KNotification::CloseWhenWidgetActivated;
+    KNotification::NotificationFlags flags = KNotification::CloseOnTimeout;
 
     const QString title = device()->name();
 
@@ -72,13 +72,13 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPackage& np)
         type = QStringLiteral("missedCall");
         icon = QStringLiteral("call-start");
         content = i18n("Missed call from %1", contactName);
-        flags |= KNotification::Persistent;
+        flags |= KNotification::Persistent; //Note that in Unity this generates a message box!
     } else if (event == QLatin1String("sms")) {
         type = QStringLiteral("smsReceived");
         icon = QStringLiteral("mail-receive");
         QString messageBody = np.get<QString>(QStringLiteral("messageBody"), QLatin1String(""));
         content = i18n("SMS from %1<br>%2", contactName, messageBody);
-        flags |= KNotification::Persistent;
+        flags |= KNotification::Persistent; //Note that in Unity this generates a message box!
     } else if (event == QLatin1String("talking")) {
         return nullptr;
     } else {
@@ -156,14 +156,10 @@ void TelephonyPlugin::showSendSmsDialog()
     QString phoneNumber = sender()->property("phoneNumber").toString();
     QString contactName = sender()->property("contactName").toString();
     QString originalMessage = sender()->property("originalMessage").toString();
-    SendSmsDialog* dialog = new SendSmsDialog(originalMessage, phoneNumber, contactName);
-    connect(dialog, &SendSmsDialog::sendSms, this, &TelephonyPlugin::sendSms);
+    SendReplyDialog* dialog = new SendReplyDialog(originalMessage, phoneNumber, contactName);
+    connect(dialog, &SendReplyDialog::sendReply, this, &TelephonyPlugin::sendSms);
     dialog->show();
-}
-
-void TelephonyPlugin::connected()
-{
-    QDBusConnection::sessionBus().registerObject(dbusPath(), this, QDBusConnection::ExportScriptableContents);
+    dialog->raise();
 }
 
 QString TelephonyPlugin::dbusPath() const
